@@ -1,7 +1,7 @@
 /*
  * util.c - utility functions for rssh
  * 
- * Copyright 2003 Derek D. Martin ( code at pizzashack dot org ).
+ * Copyright 2003-2006 Derek D. Martin ( code at pizzashack dot org ).
  *
  * This program is licensed under a BSD-style license, as follows: 
  *
@@ -209,13 +209,14 @@ char *check_command_line( char *cl, ShellOptions_t *opts )
 		return PATH_SCP;
 	}
 
-	if ( check_command(cl, opts, PATH_CVS, RSSH_ALLOW_CVS) )
+	if ( check_command(cl, opts, PATH_CVS, RSSH_ALLOW_CVS) ){
 		if ( opt_exist(cl, 'e') ){
 			fprintf(stderr, "\ninsecure -e option not allowed.");
 			log_msg("insecure -e option in cvs command line!");
 			return NULL;
 		}
 		return PATH_CVS;
+	}
 
 	if ( check_command(cl, opts, PATH_RDIST, RSSH_ALLOW_RDIST) ){
 		/* filter -P option */
